@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 #----------------------------------------------------------------------------
 
@@ -64,7 +64,7 @@ my $no_index_1_2 = {
     }
 };
 my $no_index_1_1 = {
-    'map'       => { ':key'     => { name => \&word, list => { value => \&string } },
+    'map'       => { ':key'     => { name => \&keyword, list => { value => \&string } },
     }
 };
 
@@ -91,7 +91,7 @@ my %definitions = (
 
   'optional_features'   => {
     'map'       => {
-        ':key'  => { name => \&word,
+        ':key'  => { name => \&identifier,
             'map'   => { description        => { value => \&string },
                          requires_packages  => { value => \&string },
                          requires_os        => { value => \&string },
@@ -127,7 +127,7 @@ my %definitions = (
 
   # additional user defined key/value pairs
   # note we can only validate the key name, as the structure is user defined
-  ':key'        => { name => \&word },
+  ':key'        => { name => \&keyword },
 },
 
 '1.3' => {
@@ -151,7 +151,7 @@ my %definitions = (
 
   'optional_features'   => {
     'map'       => {
-        ':key'  => { name => \&word,
+        ':key'  => { name => \&identifier,
             'map'   => { description        => { value => \&string },
                          requires_packages  => { value => \&string },
                          requires_os        => { value => \&string },
@@ -187,7 +187,7 @@ my %definitions = (
 
   # additional user defined key/value pairs
   # note we can only validate the key name, as the structure is user defined
-  ':key'        => { name => \&word },
+  ':key'        => { name => \&keyword },
 },
 
 # v1.2 is misleading, it seems to assume that a number of fields where created
@@ -220,7 +220,7 @@ my %definitions = (
 
   'optional_features'   => {
     'map'       => {
-        ':key'  => { name => \&word,
+        ':key'  => { name => \&identifier,
             'map'   => { description        => { value => \&string },
                          requires_packages  => { value => \&string },
                          requires_os        => { value => \&string },
@@ -251,7 +251,7 @@ my %definitions = (
 
   # additional user defined key/value pairs
   # note we can only validate the key name, as the structure is user defined
-  ':key'        => { name => \&word },
+  ':key'        => { name => \&keyword },
 },
 
 # note that the 1.1 spec doesn't specify optional or mandatory fields, what
@@ -275,7 +275,7 @@ my %definitions = (
 
   # additional user defined key/value pairs
   # note we can only validate the key name, as the structure is user defined
-  ':key'        => { name => \&word },
+  ':key'        => { name => \&keyword },
 },
 
 # note that the 1.0 spec doesn't specify optional or mandatory fields, what
@@ -296,7 +296,7 @@ my %definitions = (
 
   # additional user defined key/value pairs
   # note we can only validate the key name, as the structure is user defined
-  ':key'        => { name => \&word },
+  ':key'        => { name => \&keyword },
 },
 );
 
@@ -525,16 +525,22 @@ type, or 2 if a value is given but the license type is not a recommended one.
 Validates that the given key is in CamelCase, to indicate a user defined
 keyword.
 
-=item * word($self,$key,$value)
+=item * keyword($self,$key,$value)
 
 Validates that key is in an acceptable format for the META.yml specification,
-i.e. any in the character class [-_a-z].
+i.e. any in the character class [-_a-z]. 
 
 For user defined keys, although not explicitly stated in the specifications 
 (v1.0 - v1.4), the convention is to precede the key with a pattern matching 
 qr{\Ax_}i. Following this any character from the character class [-_a-zA-Z]
 can be used. This clarification has been added to v2.0 of the specification.
 
+=item * identifier($self,$key,$value)
+
+Validates that key is in an acceptable format for the META.yml specification,
+for an identifier, i.e. any that matches the regular expression
+qr/[a-z][a-z_]/i. 
+
 =item * module($self,$key,$value)
 
 Validates that a given key is in an acceptable module name format, e.g.
@@ -692,7 +698,7 @@ sub resource {
     return 0;
 }
 
-sub word {
+sub keyword {
     my ($self,$key) = @_;
     if(defined $key) {
         return 1    if($key && $key =~ /^([-_a-z]+)$/);     # spec defined
@@ -704,6 +710,17 @@ sub word {
     return 0;
 }
 
+sub identifier {
+    my ($self,$key) = @_;
+    if(defined $key) {
+        return 1    if($key && $key =~ /^([a-z][_a-z]+)$/i);    # spec 2.0 defined
+    } else {
+        $key = '<undef>';
+    }
+    $self->_error( "Key '$key' is not a legal identifier." );
+    return 0;
+}
+
 sub module {
     my ($self,$key) = @_;
     if(defined $key) {
